@@ -20,8 +20,8 @@ package handlers
 import (
 	"encoding/json"
 
-	"git.zabbix.com/ap/plugin-support/zbxerr"
 	"go.mongodb.org/mongo-driver/bson"
+	"golang.zabbix.com/sdk/zbxerr"
 )
 
 // CollectionStatsHandler
