@@ -18,8 +18,8 @@
 package handlers
 
 import (
-	"git.zabbix.com/ap/plugin-support/zbxerr"
 	"go.mongodb.org/mongo-driver/bson"
+	"golang.zabbix.com/sdk/zbxerr"
 )
 
 // VersionHandler executes 'buildInfo' command extracting and returning version
